//
//  View.swift
//  Pinch
//
//  Created by Mark Meretzky on 7/19/16.
//  Copyright © 2016 Mark Meretzky. All rights reserved.
//

import UIKit;

class View: UIView {

	let label: UILabel = UILabel();

	//Size of the label when the current pinch or spread began.
	var initialScale: CGFloat = 1;

	//Current size of the label.
	//This value is put into the .transform property of the label.
	var currentScale: CGFloat = 1;

	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder)!;
		backgroundColor = UIColor.whiteColor();

		//First subview: a fixed-size rectangle with a border around it.
		let view: UIView = UIView();
		view.layer.borderWidth = 1/3;	//1/3 points = 1 pixel
		view.layer.borderColor = UIColor.blackColor().CGColor;

		//Second subview: a variable-size label.
		label.backgroundColor = UIColor.yellowColor();
		label.textAlignment = NSTextAlignment.Center;
		label.text = "Pinch or spread me."

		//Make each subview half the size of this View.
		view.frame.size = CGSizeMake(
			bounds.size.width / 2,
			bounds.size.height / 2);

		label.frame.size = view.frame.size;

		//Put each subview at the center of this View.
		view.center = center;
		label.center = center;

		//Keep each subview at the center of this View,
		//and keep each subview half the size of the View,
		//even if the size of this View changes.

		view.autoresizingMask = [
			UIViewAutoresizing.FlexibleLeftMargin,
			UIViewAutoresizing.FlexibleRightMargin,
			UIViewAutoresizing.FlexibleTopMargin,
			UIViewAutoresizing.FlexibleBottomMargin,
			UIViewAutoresizing.FlexibleWidth,
			UIViewAutoresizing.FlexibleHeight
		];

		label.autoresizingMask = view.autoresizingMask;

		//Put the yellow label below the bordered rectangle.
		addSubview(label);
		addSubview(view);

		let recognizer: UIPinchGestureRecognizer =
			UIPinchGestureRecognizer(target: self, action: #selector(pinch(_:)));
		addGestureRecognizer(recognizer);
	}
	
	func pinch(recognizer: UIPinchGestureRecognizer) {

		if recognizer.state == UIGestureRecognizerState.Began {
			//If this is the beginning of a pinch or spread,
			//remember how big the label currently is.
			initialScale = currentScale;
		}

		else if recognizer.state == UIGestureRecognizerState.Changed {
			//If the pinch or spread is already in progress,
			//make the label bigger or smaller.
			let newScale: CGFloat = initialScale * recognizer.scale;
			
			var verdict: String;
			if newScale > currentScale {
				verdict = "spread";
			} else if newScale < currentScale {
				verdict = "pinch";
			} else {
				verdict = "neither";
			}
			currentScale = newScale;
			
			//Round to nearest thousandth.
			let rounded: String = String(format: "%.3f", currentScale);
			label.text = "\(verdict) \(rounded)";
			label.transform = CGAffineTransformMakeScale(currentScale, currentScale);
		}
	}

	/*
	// Only override drawRect: if you perform custom drawing.
	// An empty implementation adversely affects performance during animation.
	override func drawRect(rect: CGRect) {
		// Drawing code
	}
	*/

}
